Struct gsuite_api::Building [−][src]
pub struct Building {
pub kind: String,
pub name: String,
pub coordinates: Option<BuildingCoordinates>,
pub etags: String,
pub address: BuildingAddress,
pub floor_names: Vec<String>,
pub id: String,
pub description: String,
}A building.
Fields
kind: StringKind of resource this is.
name: StringThe building name as seen by users in Calendar. Must be unique for the customer. For example, “NYC-CHEL”. The maximum length is 100 characters.
coordinates: Option<BuildingCoordinates>The geographic coordinates of the center of the building, expressed as latitude and longitude in decimal degrees.
ETag of the resource.
address: BuildingAddressThe postal address of the building. See PostalAddress for details. Note that only a single address line and region code are required.
floor_names: Vec<String>The display names for all floors in this building. The floors are expected to be sorted in ascending order, from lowest floor to highest floor. For example, [“B2”, “B1”, “L”, “1”, “2”, “2M”, “3”, “PH”] Must contain at least one entry.
id: StringUnique identifier for the building. The maximum length is 100 characters.
description: StringA brief description of the building. For example, “Chelsea Market”.