Struct gsuite_api::Calendars [−][src]
pub struct Calendars {
pub next_page_token: String,
pub next_sync_token: String,
pub kind: String,
pub etag: String,
pub trigger_event: String,
pub items: Vec<Calendar>,
}A list of calendars. FROM: https://developers.google.com/calendar/v3/reference/calendarList/list
Fields
next_page_token: StringToken used to access next page of this result.
next_sync_token: StringToken used at a later point in time to retrieve only the entries that have changed since this result was returned. Omitted if further results are available, in which case nextPageToken is provided.
kind: StringKind of resource this is.
etag: StringETag of the resource.
trigger_event: StringEvent that triggered this response (only used in case of Push Response)
items: Vec<Calendar>List of group objects.