[−][src]Struct gsuite_api::User
A user.
Fields
addresses: Option<String>posix_accounts: Option<String>phones: Option<Vec<UserPhone>>locations: Option<Vec<UserLocation>>is_delegated_admin: Option<bool>Boolean indicating if the user is delegated admin (Read-only)
thumbnail_photo_etag: Option<String>ETag of the user's photo (Read-only)
suspended: Option<bool>Indicates if user is suspended.
keywords: Option<String>kind: Option<String>Kind of resource this is.
id: Option<String>Unique identifier of User (Read-only)
aliases: Option<Vec<String>>List of aliases (Read-only)
non_editable_aliases: Option<Vec<String>>List of non editable aliases (Read-only)
archived: Option<bool>Indicates if user is archived.
deletion_time: Option<String>suspension_reason: Option<String>Suspension reason if user is suspended (Read-only)
thumbnail_photo_url: Option<String>Photo Url of the user (Read-only)
is_enrolled_in2_sv: Option<bool>Is enrolled in 2-step verification (Read-only)
include_in_global_address_list: Option<bool>Boolean indicating if user is included in Global Address List
relations: Option<String>languages: Option<String>is_admin: Option<bool>Boolean indicating if the user is admin (Read-only)
etag: Option<String>ETag of the resource.
last_login_time: Option<String>User's last login time. (Read-only)
org_unit_path: Option<String>OrgUnit of User
agreed_to_terms: Option<bool>Indicates if user has agreed to terms (Read-only)
external_ids: Option<String>ip_whitelisted: Option<bool>Boolean indicating if ip is whitelisted
ssh_public_keys: Option<Vec<UserSSHKey>>custom_schemas: Option<HashMap<String, UserCustomProperties>>Custom fields of the user.
is_enforced_in2_sv: Option<bool>Is 2-step verification enforced (Read-only)
is_mailbox_setup: Option<bool>Is mailbox setup (Read-only)
password: Option<String>User's password
emails: Option<Vec<UserEmail>>organizations: Option<String>primary_email: Option<String>username of User
hash_function: Option<String>Hash function name for password. Supported are MD5, SHA-1 and crypt
name: Option<UserName>User's name
gender: Option<UserGender>notes: Option<String>creation_time: Option<String>User's G Suite account creation time. (Read-only)
websites: Option<String>change_password_at_next_login: Option<bool>Boolean indicating if the user should change password in next login
ims: Option<String>customer_id: Option<String>CustomerId of User (Read-only)
recovery_email: Option<String>Recovery email of the user
recovery_phone: Option<String>Recovery phone of the user
Implementations
impl User[src]
pub async fn update<'_, '_>(
__arg0: Self,
user: &'_ UserConfig,
domain: &'_ str,
change_password: bool
) -> User[src]
__arg0: Self,
user: &'_ UserConfig,
domain: &'_ str,
change_password: bool
) -> User
Update a user.