Struct gsuite_api::UserAddress [−][src]
pub struct UserAddress {Show fields
pub country: String,
pub country_code: String,
pub custom_type: String,
pub extended_address: String,
pub formatted: String,
pub locality: String,
pub po_box: String,
pub postal_code: String,
pub primary: bool,
pub region: String,
pub source_is_structured: bool,
pub street_address: String,
pub typev: String,
}A user’s address.
Fields
country: Stringcountry_code: StringThe country code. Uses the ISO 3166-1 standard.
custom_type: StringIf the value of type is custom, this property contains the custom type string.
extended_address: StringFor extended addresses, such as an address that includes a sub-region.
formatted: StringA full and unstructured postal address. This is not synced with the structured address fields.
locality: StringThe town or city of the address.
po_box: Stringpostal_code: StringThe ZIP or postal code, if applicable.
primary: boolregion: StringThe abbreviated province or state.
source_is_structured: boolIndicates if the user-supplied address was formatted. Formatted addresses are not currently supported.
street_address: StringThe street address, such as 1600 Amphitheatre Parkway. Whitespace within the string is ignored; however, newlines are significant.
typev: StringTrait Implementations
impl Clone for UserAddress[src]
impl Clone for UserAddress[src]fn clone(&self) -> UserAddress[src]
pub fn clone_from(&mut self, source: &Self)1.0.0[src]
impl Default for UserAddress[src]
impl Default for UserAddress[src]fn default() -> UserAddress[src]
impl<'de> Deserialize<'de> for UserAddress[src]
impl<'de> Deserialize<'de> for UserAddress[src]fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, [src]
__D: Deserializer<'de>,
impl Serialize for UserAddress[src]
impl Serialize for UserAddress[src]Auto Trait Implementations
impl RefUnwindSafe for UserAddress
impl RefUnwindSafe for UserAddressimpl Send for UserAddress
impl Send for UserAddressimpl Sync for UserAddress
impl Sync for UserAddressimpl Unpin for UserAddress
impl Unpin for UserAddressimpl UnwindSafe for UserAddress
impl UnwindSafe for UserAddressBlanket Implementations
impl<T> DeserializeOwned for T where
T: for<'de> Deserialize<'de>, [src]
impl<T> DeserializeOwned for T where
T: for<'de> Deserialize<'de>, [src]impl<T> Instrument for T[src]
impl<T> Instrument for T[src]pub fn instrument(self, span: Span) -> Instrumented<Self>[src]
pub fn in_current_span(self) -> Instrumented<Self>[src]
impl<T> Instrument for T[src]
impl<T> Instrument for T[src]pub fn instrument(self, span: Span) -> Instrumented<Self>[src]
pub fn in_current_span(self) -> Instrumented<Self>[src]
impl<V, T> VZip<V> for T where
V: MultiLane<T>,
impl<V, T> VZip<V> for T where
V: MultiLane<T>,