Struct gsuite_api::UserLocation [−][src]
pub struct UserLocation {
pub area: String,
pub building_id: String,
pub custom_type: String,
pub desk_code: String,
pub floor_name: String,
pub floor_section: String,
pub typev: String,
}A user’s location.
Fields
area: Stringbuilding_id: StringUnique ID for the building a resource is located in.
custom_type: StringIf the value of type is custom, this property contains the custom type string.
desk_code: StringMost specific textual code of individual desk location.
floor_name: StringName of the floor a resource is located on.
floor_section: StringFloor section. More specific location within the floor. For example, if a floor is divided into sections “A”, “B”, and “C”, this field would identify one of those values.
typev: StringTrait Implementations
impl Clone for UserLocation[src]
impl Clone for UserLocation[src]fn clone(&self) -> UserLocation[src]
pub fn clone_from(&mut self, source: &Self)1.0.0[src]
impl Default for UserLocation[src]
impl Default for UserLocation[src]fn default() -> UserLocation[src]
impl<'de> Deserialize<'de> for UserLocation[src]
impl<'de> Deserialize<'de> for UserLocation[src]fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, [src]
__D: Deserializer<'de>,
impl Serialize for UserLocation[src]
impl Serialize for UserLocation[src]Auto Trait Implementations
impl RefUnwindSafe for UserLocation
impl RefUnwindSafe for UserLocationimpl Send for UserLocation
impl Send for UserLocationimpl Sync for UserLocation
impl Sync for UserLocationimpl Unpin for UserLocation
impl Unpin for UserLocationimpl UnwindSafe for UserLocation
impl UnwindSafe for UserLocationBlanket Implementations
impl<T> DeserializeOwned for T where
T: for<'de> Deserialize<'de>, [src]
impl<T> DeserializeOwned for T where
T: for<'de> Deserialize<'de>, [src]impl<T> Instrument for T[src]
impl<T> Instrument for T[src]pub fn instrument(self, span: Span) -> Instrumented<Self>[src]
pub fn in_current_span(self) -> Instrumented<Self>[src]
impl<T> Instrument for T[src]
impl<T> Instrument for T[src]pub fn instrument(self, span: Span) -> Instrumented<Self>[src]
pub fn in_current_span(self) -> Instrumented<Self>[src]
impl<V, T> VZip<V> for T where
V: MultiLane<T>,
impl<V, T> VZip<V> for T where
V: MultiLane<T>,