pub struct Tokens {
pub client: Client,
}Fields
client: ClientImplementations
Sourceimpl Tokens
impl Tokens
Sourcepub async fn list(
&self,
user_key: &str,
) -> Result<Response<Tokens>, ClientError>
pub async fn list( &self, user_key: &str, ) -> Result<Response<Tokens>, ClientError>
This function performs a GET to the /admin/directory/v1/users/{userKey}/tokens endpoint.
Returns the set of tokens specified user has issued to 3rd party applications.
Parameters:
user_key: &str– Identifies the user in the API request. The value can be the user’s primary email address, alias email address, or unique user ID.
Sourcepub async fn get(
&self,
user_key: &str,
client_id: &str,
) -> Result<Response<Token>, ClientError>
pub async fn get( &self, user_key: &str, client_id: &str, ) -> Result<Response<Token>, ClientError>
This function performs a GET to the /admin/directory/v1/users/{userKey}/tokens/{clientId} endpoint.
Gets information about an access token issued by a user.
Parameters:
user_key: &str– Identifies the user in the API request. The value can be the user’s primary email address, alias email address, or unique user ID.client_id: &str– The Client ID of the application the token is issued to.
Sourcepub async fn delete(
&self,
user_key: &str,
client_id: &str,
) -> Result<Response<()>, ClientError>
pub async fn delete( &self, user_key: &str, client_id: &str, ) -> Result<Response<()>, ClientError>
This function performs a DELETE to the /admin/directory/v1/users/{userKey}/tokens/{clientId} endpoint.
Deletes all access tokens issued by a user for an application.
Parameters:
user_key: &str– Identifies the user in the API request. The value can be the user’s primary email address, alias email address, or unique user ID.client_id: &str– The Client ID of the application the token is issued to.